Update of /cvsroot/audacity/audacity-src/src/effects/ladspa
In directory 23jxhf1.ch3.sourceforge.com:/tmp/cvs-serv19679/effects/ladspa

Modified Files:
        LadspaEffect.cpp 
Log Message:
Fixed Bugs Related with Clearing tracks inside Groups (p.e. Truncate Effect 
Bug, Clear WaveTrack between Time and Label Track)
Removed some warnings.
Added Track::All enum to match all tracks. Edited TrackListOfKindIterator to 
match Track::All meaning.

Index: LadspaEffect.cpp
===================================================================
RCS file: /cvsroot/audacity/audacity-src/src/effects/ladspa/LadspaEffect.cpp,v
retrieving revision 1.53
retrieving revision 1.54
diff -u -d -r1.53 -r1.54
--- LadspaEffect.cpp    29 May 2009 07:14:46 -0000      1.53
+++ LadspaEffect.cpp    18 Jun 2009 00:40:06 -0000      1.54
@@ -228,10 +228,10 @@
 
 bool LadspaEffect::Process()
 {
-   this->CopyInputWaveTracks(); // Set up mOutputWaveTracks.
+   this->CopyInputTracks(); // Set up mOutputTracks.
    bool bGoodResult = true;
 
-   TrackListIterator iter(mOutputWaveTracks);
+   TrackListIterator iter(mOutputTracks);
    int count = 0;
    Track *left = iter.First();
    Track *right;
@@ -264,7 +264,7 @@
       count++;
    }
 
-   this->ReplaceProcessedWaveTracks(bGoodResult); 
+   this->ReplaceProcessedTracks(bGoodResult); 
    return bGoodResult;
 }
 


------------------------------------------------------------------------------
Crystal Reports - New Free Runtime and 30 Day Trial
Check out the new simplified licensing option that enables unlimited
royalty-free distribution of the report engine for externally facing 
server and web deployment.
http://p.sf.net/sfu/businessobjects
_______________________________________________
Audacity-cvs mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/audacity-cvs

Reply via email to